| crew_class_launcher_cluster | R Documentation |
R6 class to help develop specific cluster launcher plugins.
See crew_launcher_cluster().
The template files at
https://github.com/mschubert/clustermq/tree/master/inst
informed the development of the crew launcher plugins in
crew.cluster, and we would like to thank
Michael Schubert for developing clustermq and releasing it under
the permissive Apache License 2.0.
See the NOTICE and README.md files in the crew.cluster
source code for additional attribution.
crew::crew_class_launcher -> crew_class_launcher_cluster
options_clusterSee crew_launcher_cluster().
crew::crew_class_launcher$call()crew::crew_class_launcher$crashes()crew::crew_class_launcher$launch()crew::crew_class_launcher$launch_worker()crew::crew_class_launcher$poll()crew::crew_class_launcher$scale()crew::crew_class_launcher$set_name()crew::crew_class_launcher$settings()crew::crew_class_launcher$start()crew::crew_class_launcher$terminate()crew::crew_class_launcher$terminate_workers()new()Abstract launcher constructor.
crew_class_launcher_cluster$new( name = NULL, workers = NULL, seconds_interval = NULL, seconds_timeout = NULL, seconds_launch = NULL, seconds_idle = NULL, seconds_wall = NULL, tasks_max = NULL, tasks_timers = NULL, reset_globals = NULL, reset_packages = NULL, reset_options = NULL, garbage_collection = NULL, tls = NULL, r_arguments = NULL, options_metrics = NULL, options_cluster = NULL )
nameSee crew_launcher_cluster().
workersSee crew_launcher_cluster().
seconds_intervalSee crew_launcher_cluster().
seconds_timeoutSee crew_launcher_cluster().
seconds_launchSee crew_launcher_cluster().
seconds_idleSee crew_launcher_cluster().
seconds_wallSee crew_launcher_cluster().
tasks_maxSee crew_launcher_cluster().
tasks_timersSee crew_launcher_cluster().
reset_globalsSee crew_launcher_cluster().
reset_packagesSee crew_launcher_cluster().
reset_optionsSee crew_launcher_cluster().
garbage_collectionSee crew_launcher_cluster().
tlsSee crew_launcher_cluster().
r_argumentsSee crew_launcher_cluster().
options_metricsSee crew_launcher_cluster().
options_clusterSee crew_launcher_cluster().
An abstract launcher object.
validate()Validate the launcher.
crew_class_launcher_cluster$validate()
NULL (invisibly). Throws an error if a field is invalid.
launch_workers()Launch a job array
crew_class_launcher_cluster$launch_workers(call, n)
callCharacter string, a namespaced call to
crew::crew_worker()
which will run in the worker and accept tasks.
nPositive integer of length 1, number of workers to launch in the current round of auto-scaling.
The call argument is R code that will run to
initiate the worker.
A handle object to allow the termination of the worker later on.
Other cluster:
crew_class_monitor_cluster,
crew_launcher_cluster(),
crew_monitor_cluster(),
crew_options_cluster()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.