| crew_class_launcher_sge | R Documentation |
R6 class to launch and manage SGE workers.
See crew_launcher_sge().
The template files at
https://github.com/mschubert/clustermq/tree/master/inst
informed the development of the crew launcher plugins in
crew.cluster, and we would like to thank
Michael Schubert for developing clustermq and releasing it under
the permissive Apache License 2.0.
See the NOTICE and README.md files in the crew.cluster
source code for additional attribution.
crew::crew_class_launcher -> crew.cluster::crew_class_launcher_cluster -> crew_class_launcher_sge
crew::crew_class_launcher$call()crew::crew_class_launcher$crashes()crew::crew_class_launcher$launch()crew::crew_class_launcher$launch_worker()crew::crew_class_launcher$poll()crew::crew_class_launcher$scale()crew::crew_class_launcher$set_name()crew::crew_class_launcher$settings()crew::crew_class_launcher$start()crew::crew_class_launcher$terminate()crew::crew_class_launcher$terminate_workers()crew.cluster::crew_class_launcher_cluster$initialize()crew.cluster::crew_class_launcher_cluster$launch_workers()validate()Validate the launcher.
crew_class_launcher_sge$validate()
NULL (invisibly). Throws an error if a field is invalid.
script()Generate the job script.
crew_class_launcher_sge$script(name, n)
nameCharacter of length 1, name of the job. For inspection purposes, you can supply a mock job name.
nPositive integer of length 1, number of crew workers (i.e. cluster jobs) to launch in the current round of auto-scaling.
Includes everything except the worker-instance-specific
job name and the worker-instance-specific
call to crew::crew_worker(), both of which get inserted at
the bottom of the script at launch time.
Character vector of the lines of the job script.
if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
launcher <- crew_launcher_sge(
sge_cores = 2,
sge_memory_gigabytes_required = 4
)
launcher$script(name = "my_job_name")
}
Other sge:
crew_class_monitor_sge,
crew_controller_sge(),
crew_launcher_sge(),
crew_monitor_sge(),
crew_options_sge()
## ------------------------------------------------
## Method `crew_class_launcher_sge$script`
## ------------------------------------------------
if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
launcher <- crew_launcher_sge(
sge_cores = 2,
sge_memory_gigabytes_required = 4
)
launcher$script(name = "my_job_name")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.